@@ -112,7 +112,7 @@ def _parse_date_part(self):
 def _div0_to_if(args):
     cond = exp.EQ(this=seq_get(args, 1), expression=exp.Literal.number(0))
     true = exp.Literal.number(0)
-    false = exp.FloatDiv(this=seq_get(args, 0), expression=seq_get(args, 1))
+    false = exp.Div(this=seq_get(args, 0), expression=seq_get(args, 1))
     return exp.If(this=cond, true=true, false=false)
 
 
@@ -174,6 +174,7 @@ class Snowflake(Dialect):
         FUNCTIONS = {
             **parser.Parser.FUNCTIONS,
             "ARRAYAGG": exp.ArrayAgg.from_arg_list,
+            "ARRAY_CONSTRUCT": exp.Array.from_arg_list,
             "ARRAY_TO_STRING": exp.ArrayJoin.from_arg_list,
             "DATEADD": lambda args: exp.DateAdd(
                 this=seq_get(args, 2),
@@ -189,16 +190,17 @@ class Snowflake(Dialect):
                 unit=exp.Literal.string(seq_get(args, 0).name),  # type: ignore
                 this=seq_get(args, 1),
             ),
+            "DECODE": exp.Matches.from_arg_list,
             "DIV0": _div0_to_if,
             "IFF": exp.If.from_arg_list,
-            "TO_ARRAY": exp.Array.from_arg_list,
-            "TO_TIMESTAMP": _snowflake_to_timestamp,
-            "ARRAY_CONSTRUCT": exp.Array.from_arg_list,
-            "RLIKE": exp.RegexpLike.from_arg_list,
-            "DECODE": exp.Matches.from_arg_list,
-            "OBJECT_CONSTRUCT": parser.parse_var_map,
-            "ZEROIFNULL": _zeroifnull_to_if,
             "NULLIFZERO": _nullifzero_to_if,
+            "OBJECT_CONSTRUCT": parser.parse_var_map,
+            "RLIKE": exp.RegexpLike.from_arg_list,
+            "SQUARE": lambda args: exp.Pow(this=seq_get(args, 0), expression=exp.Literal.number(2)),
+            "TO_ARRAY": exp.Array.from_arg_list,
+            "TO_VARCHAR": exp.ToChar.from_arg_list,
+            "TO_TIMESTAMP": _snowflake_to_timestamp,
+            "ZEROIFNULL": _zeroifnull_to_if,
         }
 
         FUNCTION_PARSERS = {
@@ -234,8 +236,6 @@ class Snowflake(Dialect):
             "SET": lambda self: self._parse_alter_table_set_tag(),
         }
 
-        INTEGER_DIVISION = False
-
         def _parse_alter_table_set_tag(self, unset: bool = False) -> exp.Expression:
             self._match_text_seq("TAG")
             parser = t.cast(t.Callable, self._parse_id_var if unset else self._parse_conjunction)
@@ -268,7 +268,6 @@ class Snowflake(Dialect):
 
     class Generator(generator.Generator):
         PARAMETER_TOKEN = "$"
-        INTEGER_DIVISION = False
         MATCHED_BY_SOURCE = False
 
         TRANSFORMS = {
@@ -291,6 +290,7 @@ class Snowflake(Dialect):
             exp.TimeStrToTime: timestrtotime_sql,
             exp.TimeToUnix: lambda self, e: f"EXTRACT(epoch_second FROM {self.sql(e, 'this')})",
             exp.Trim: lambda self, e: self.func("TRIM", e.this, e.expression),
+            exp.ToChar: lambda self, e: self.function_fallback_sql(e),
             exp.TsOrDsToDate: ts_or_ds_to_date_sql("snowflake"),
             exp.UnixToTime: _unix_to_time_sql,
             exp.DayOfWeek: rename_func("DAYOFWEEK"),
